==> hilt-android-compiler-2.44-sources.jar: dagger/hilt/android/processor/internal/androidentrypoint/AutoValue_AndroidEntryPointMetadata.java <==
package dagger.hilt.android.processor.internal.androidentrypoint;

import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import com.squareup.javapoet.ClassName;
import com.squareup.javapoet.CodeBlock;
import com.squareup.javapoet.TypeName;
import java.lang.Override;
import java.lang.SuppressWarnings;
import java.util.Optional;
import javax.lang.model.element.TypeElement;

final class AutoValue_AndroidEntryPointMetadata extends $AutoValue_AndroidEntryPointMetadata {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile AndroidEntryPointMetadata rootMetadata;

  AutoValue_AndroidEntryPointMetadata(TypeElement element$, TypeElement baseElement$,
      ClassName generatedClassName$, boolean requiresBytecodeInjection$,
      AndroidEntryPointMetadata.AndroidType androidType$,
      Optional<AndroidEntryPointMetadata> baseMetadata$,
      ImmutableSet<ClassName> installInComponents$, TypeName componentManager$,
      Optional<CodeBlock> componentManagerInitArgs$) {
    super(element$, baseElement$, generatedClassName$, requiresBytecodeInjection$, androidType$, baseMetadata$, installInComponents$, componentManager$, componentManagerInitArgs$);
  }

  @Override
  public AndroidEntryPointMetadata rootMetadata() {
    if (rootMetadata == null) {
      synchronized (this) {
        if (rootMetadata == null) {
          rootMetadata = super.rootMetadata();
          if (rootMetadata == null) {
            throw new NullPointerException("rootMetadata() cannot return null");
          }
        }
      }
    }
    return rootMetadata;
  }
}

==> hilt-android-compiler-2.56.2-sources.jar: dagger/hilt/android/processor/internal/androidentrypoint/AutoValue_AndroidEntryPointMetadata.java <==
package dagger.hilt.android.processor.internal.androidentrypoint;

import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import com.squareup.javapoet.ClassName;
import com.squareup.javapoet.CodeBlock;
import com.squareup.javapoet.TypeName;
import java.lang.Override;
import java.lang.SuppressWarnings;
import java.util.Optional;

final class AutoValue_AndroidEntryPointMetadata extends $AutoValue_AndroidEntryPointMetadata {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile AndroidEntryPointMetadata rootMetadata;

  AutoValue_AndroidEntryPointMetadata(XTypeElement element$, XTypeElement baseElement$,
      ClassName generatedClassName$, boolean requiresBytecodeInjection$,
      AndroidEntryPointMetadata.AndroidType androidType$,
      Optional<AndroidEntryPointMetadata> baseMetadata$,
      ImmutableSet<ClassName> installInComponents$, TypeName componentManager$,
      Optional<CodeBlock> componentManagerInitArgs$) {
    super(element$, baseElement$, generatedClassName$, requiresBytecodeInjection$, androidType$, baseMetadata$, installInComponents$, componentManager$, componentManagerInitArgs$);
  }

  @Override
  public AndroidEntryPointMetadata rootMetadata() {
    if (rootMetadata == null) {
      synchronized (this) {
        if (rootMetadata == null) {
          rootMetadata = super.rootMetadata();
          if (rootMetadata == null) {
            throw new NullPointerException("rootMetadata() cannot return null");
          }
        }
      }
    }
    return rootMetadata;
  }
}
